pub(crate) struct SameFormattingContextBlock {
pub base: LayoutBoxBase,
pub contents: BlockContainer,
pub contains_floats: bool,
}Expand description
A block in block flow that does not establish a new formatting context.
Fields
base: LayoutBoxBasecontents: BlockContainercontains_floats: boolImplementations
Sourceimpl SameFormattingContextBlock
impl SameFormattingContextBlock
pub(crate) fn new( base: LayoutBoxBase, contents: BlockContainer, contains_floats: bool, ) -> Self
pub(crate) fn layout_style(&self) -> LayoutStyle<'_>
pub(crate) fn repair_style( &mut self, context: &SharedStyleContext<'_>, node: &ServoLayoutNode<'_>, new_style: &ServoArc<ComputedValues>, )
pub(crate) fn inline_content_sizes( &self, layout_context: &LayoutContext<'_>, constraint_space: &ConstraintSpace<'_>, ) -> InlineContentSizesResult
Sourcepub(crate) fn layout_in_flow_non_replaced_block_level_cached(
&self,
layout_context: &LayoutContext<'_>,
positioning_context: &mut PositioningContext,
containing_block: &ContainingBlock<'_>,
sequential_layout_state: Option<&mut SequentialLayoutState>,
collapsible_with_parent_start_margin: Option<CollapsibleWithParentStartMargin>,
ignore_block_margins_for_stretch: LogicalSides1D<bool>,
has_inline_parent: bool,
) -> Arc<BoxFragment>
pub(crate) fn layout_in_flow_non_replaced_block_level_cached( &self, layout_context: &LayoutContext<'_>, positioning_context: &mut PositioningContext, containing_block: &ContainingBlock<'_>, sequential_layout_state: Option<&mut SequentialLayoutState>, collapsible_with_parent_start_margin: Option<CollapsibleWithParentStartMargin>, ignore_block_margins_for_stretch: LogicalSides1D<bool>, has_inline_parent: bool, ) -> Arc<BoxFragment>
Lay out a normal flow non-replaced SameFormattingContextBlock, properly taking
into account relative positioning. This version also handles caching the layout
results and fetching the results from the cache, if they are still valid.
Sourcefn layout_in_flow_non_replaced_block_level(
&self,
layout_context: &LayoutContext<'_>,
positioning_context: &mut PositioningContext,
containing_block: &ContainingBlock<'_>,
sequential_layout_state: Option<&mut SequentialLayoutState>,
collapsible_with_parent_start_margin: Option<CollapsibleWithParentStartMargin>,
ignore_block_margins_for_stretch: LogicalSides1D<bool>,
has_inline_parent: bool,
) -> BoxFragment
fn layout_in_flow_non_replaced_block_level( &self, layout_context: &LayoutContext<'_>, positioning_context: &mut PositioningContext, containing_block: &ContainingBlock<'_>, sequential_layout_state: Option<&mut SequentialLayoutState>, collapsible_with_parent_start_margin: Option<CollapsibleWithParentStartMargin>, ignore_block_margins_for_stretch: LogicalSides1D<bool>, has_inline_parent: bool, ) -> BoxFragment
Lay out a normal flow non-replaced SameFormattingContextBlock.